depends = ('ITKPyBase', 'ITKTransform', 'ITKSpatialObjects', 'ITKImageFilterBase', 'ITKImageCompose', )
templates = (
  ('AccumulateImageFilter', 'itk::AccumulateImageFilter', 'itkAccumulateImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('AccumulateImageFilter', 'itk::AccumulateImageFilter', 'itkAccumulateImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('AccumulateImageFilter', 'itk::AccumulateImageFilter', 'itkAccumulateImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('AccumulateImageFilter', 'itk::AccumulateImageFilter', 'itkAccumulateImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('AccumulateImageFilter', 'itk::AccumulateImageFilter', 'itkAccumulateImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('AccumulateImageFilter', 'itk::AccumulateImageFilter', 'itkAccumulateImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('AccumulateImageFilter', 'itk::AccumulateImageFilter', 'itkAccumulateImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('AccumulateImageFilter', 'itk::AccumulateImageFilter', 'itkAccumulateImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('AccumulateImageFilter', 'itk::AccumulateImageFilter', 'itkAccumulateImageFilterID2ID2', True, 'itk::Image< double,2 >, itk::Image< double,2 >'),
  ('AccumulateImageFilter', 'itk::AccumulateImageFilter', 'itkAccumulateImageFilterID3ID3', True, 'itk::Image< double,3 >, itk::Image< double,3 >'),
  ('BinaryProjectionImageFilter', 'itk::BinaryProjectionImageFilter', 'itkBinaryProjectionImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('BinaryProjectionImageFilter', 'itk::BinaryProjectionImageFilter', 'itkBinaryProjectionImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('BinaryProjectionImageFilter', 'itk::BinaryProjectionImageFilter', 'itkBinaryProjectionImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('BinaryProjectionImageFilter', 'itk::BinaryProjectionImageFilter', 'itkBinaryProjectionImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('BinaryProjectionImageFilter', 'itk::BinaryProjectionImageFilter', 'itkBinaryProjectionImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('BinaryProjectionImageFilter', 'itk::BinaryProjectionImageFilter', 'itkBinaryProjectionImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('BinaryProjectionImageFilter', 'itk::BinaryProjectionImageFilter', 'itkBinaryProjectionImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('BinaryProjectionImageFilter', 'itk::BinaryProjectionImageFilter', 'itkBinaryProjectionImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('BinaryProjectionImageFilter', 'itk::BinaryProjectionImageFilter', 'itkBinaryProjectionImageFilterID2ID2', True, 'itk::Image< double,2 >, itk::Image< double,2 >'),
  ('BinaryProjectionImageFilter', 'itk::BinaryProjectionImageFilter', 'itkBinaryProjectionImageFilterID3ID3', True, 'itk::Image< double,3 >, itk::Image< double,3 >'),
  ('BinaryProjectionImageFilter', 'itk::BinaryProjectionImageFilter', 'itkBinaryProjectionImageFilterISS3ISS2', True, 'itk::Image< signed short,3 >,itk::Image< signed short,2 >'),
  ('BinaryProjectionImageFilter', 'itk::BinaryProjectionImageFilter', 'itkBinaryProjectionImageFilterIUC3IUC2', True, 'itk::Image< unsigned char,3 >,itk::Image< unsigned char,2 >'),
  ('BinaryProjectionImageFilter', 'itk::BinaryProjectionImageFilter', 'itkBinaryProjectionImageFilterIUS3IUS2', True, 'itk::Image< unsigned short,3 >,itk::Image< unsigned short,2 >'),
  ('ImageMomentsCalculator', 'itk::ImageMomentsCalculator', 'itkImageMomentsCalculatorISS2', True, 'itk::Image< signed short,2 >'),
  ('ImageMomentsCalculator', 'itk::ImageMomentsCalculator', 'itkImageMomentsCalculatorISS3', True, 'itk::Image< signed short,3 >'),
  ('ImageMomentsCalculator', 'itk::ImageMomentsCalculator', 'itkImageMomentsCalculatorIUC2', True, 'itk::Image< unsigned char,2 >'),
  ('ImageMomentsCalculator', 'itk::ImageMomentsCalculator', 'itkImageMomentsCalculatorIUC3', True, 'itk::Image< unsigned char,3 >'),
  ('ImageMomentsCalculator', 'itk::ImageMomentsCalculator', 'itkImageMomentsCalculatorIUS2', True, 'itk::Image< unsigned short,2 >'),
  ('ImageMomentsCalculator', 'itk::ImageMomentsCalculator', 'itkImageMomentsCalculatorIUS3', True, 'itk::Image< unsigned short,3 >'),
  ('ImageMomentsCalculator', 'itk::ImageMomentsCalculator', 'itkImageMomentsCalculatorIF2', True, 'itk::Image< float,2 >'),
  ('ImageMomentsCalculator', 'itk::ImageMomentsCalculator', 'itkImageMomentsCalculatorIF3', True, 'itk::Image< float,3 >'),
  ('ImageMomentsCalculator', 'itk::ImageMomentsCalculator', 'itkImageMomentsCalculatorID2', True, 'itk::Image< double,2 >'),
  ('ImageMomentsCalculator', 'itk::ImageMomentsCalculator', 'itkImageMomentsCalculatorID3', True, 'itk::Image< double,3 >'),
  ('ImagePCAShapeModelEstimator', 'itk::ImagePCAShapeModelEstimator', 'itkImagePCAShapeModelEstimatorISS2IF2', True, 'itk::Image< signed short,2 >, itk::Image< float,2 >'),
  ('ImagePCAShapeModelEstimator', 'itk::ImagePCAShapeModelEstimator', 'itkImagePCAShapeModelEstimatorISS2ID2', True, 'itk::Image< signed short,2 >, itk::Image< double,2 >'),
  ('ImagePCAShapeModelEstimator', 'itk::ImagePCAShapeModelEstimator', 'itkImagePCAShapeModelEstimatorIUC2IF2', True, 'itk::Image< unsigned char,2 >, itk::Image< float,2 >'),
  ('ImagePCAShapeModelEstimator', 'itk::ImagePCAShapeModelEstimator', 'itkImagePCAShapeModelEstimatorIUC2ID2', True, 'itk::Image< unsigned char,2 >, itk::Image< double,2 >'),
  ('ImagePCAShapeModelEstimator', 'itk::ImagePCAShapeModelEstimator', 'itkImagePCAShapeModelEstimatorIUS2IF2', True, 'itk::Image< unsigned short,2 >, itk::Image< float,2 >'),
  ('ImagePCAShapeModelEstimator', 'itk::ImagePCAShapeModelEstimator', 'itkImagePCAShapeModelEstimatorIUS2ID2', True, 'itk::Image< unsigned short,2 >, itk::Image< double,2 >'),
  ('ImagePCAShapeModelEstimator', 'itk::ImagePCAShapeModelEstimator', 'itkImagePCAShapeModelEstimatorIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('ImagePCAShapeModelEstimator', 'itk::ImagePCAShapeModelEstimator', 'itkImagePCAShapeModelEstimatorIF2ID2', True, 'itk::Image< float,2 >, itk::Image< double,2 >'),
  ('ImagePCAShapeModelEstimator', 'itk::ImagePCAShapeModelEstimator', 'itkImagePCAShapeModelEstimatorID2IF2', True, 'itk::Image< double,2 >, itk::Image< float,2 >'),
  ('ImagePCAShapeModelEstimator', 'itk::ImagePCAShapeModelEstimator', 'itkImagePCAShapeModelEstimatorID2ID2', True, 'itk::Image< double,2 >, itk::Image< double,2 >'),
  ('ImagePCAShapeModelEstimator', 'itk::ImagePCAShapeModelEstimator', 'itkImagePCAShapeModelEstimatorISS3IF3', True, 'itk::Image< signed short,3 >, itk::Image< float,3 >'),
  ('ImagePCAShapeModelEstimator', 'itk::ImagePCAShapeModelEstimator', 'itkImagePCAShapeModelEstimatorISS3ID3', True, 'itk::Image< signed short,3 >, itk::Image< double,3 >'),
  ('ImagePCAShapeModelEstimator', 'itk::ImagePCAShapeModelEstimator', 'itkImagePCAShapeModelEstimatorIUC3IF3', True, 'itk::Image< unsigned char,3 >, itk::Image< float,3 >'),
  ('ImagePCAShapeModelEstimator', 'itk::ImagePCAShapeModelEstimator', 'itkImagePCAShapeModelEstimatorIUC3ID3', True, 'itk::Image< unsigned char,3 >, itk::Image< double,3 >'),
  ('ImagePCAShapeModelEstimator', 'itk::ImagePCAShapeModelEstimator', 'itkImagePCAShapeModelEstimatorIUS3IF3', True, 'itk::Image< unsigned short,3 >, itk::Image< float,3 >'),
  ('ImagePCAShapeModelEstimator', 'itk::ImagePCAShapeModelEstimator', 'itkImagePCAShapeModelEstimatorIUS3ID3', True, 'itk::Image< unsigned short,3 >, itk::Image< double,3 >'),
  ('ImagePCAShapeModelEstimator', 'itk::ImagePCAShapeModelEstimator', 'itkImagePCAShapeModelEstimatorIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('ImagePCAShapeModelEstimator', 'itk::ImagePCAShapeModelEstimator', 'itkImagePCAShapeModelEstimatorIF3ID3', True, 'itk::Image< float,3 >, itk::Image< double,3 >'),
  ('ImagePCAShapeModelEstimator', 'itk::ImagePCAShapeModelEstimator', 'itkImagePCAShapeModelEstimatorID3IF3', True, 'itk::Image< double,3 >, itk::Image< float,3 >'),
  ('ImagePCAShapeModelEstimator', 'itk::ImagePCAShapeModelEstimator', 'itkImagePCAShapeModelEstimatorID3ID3', True, 'itk::Image< double,3 >, itk::Image< double,3 >'),
  ('ImageShapeModelEstimatorBase', 'itk::ImageShapeModelEstimatorBase', 'itkImageShapeModelEstimatorBaseISS2IF2', True, 'itk::Image< signed short,2 >, itk::Image< float,2 >'),
  ('ImageShapeModelEstimatorBase', 'itk::ImageShapeModelEstimatorBase', 'itkImageShapeModelEstimatorBaseISS2ID2', True, 'itk::Image< signed short,2 >, itk::Image< double,2 >'),
  ('ImageShapeModelEstimatorBase', 'itk::ImageShapeModelEstimatorBase', 'itkImageShapeModelEstimatorBaseIUC2IF2', True, 'itk::Image< unsigned char,2 >, itk::Image< float,2 >'),
  ('ImageShapeModelEstimatorBase', 'itk::ImageShapeModelEstimatorBase', 'itkImageShapeModelEstimatorBaseIUC2ID2', True, 'itk::Image< unsigned char,2 >, itk::Image< double,2 >'),
  ('ImageShapeModelEstimatorBase', 'itk::ImageShapeModelEstimatorBase', 'itkImageShapeModelEstimatorBaseIUS2IF2', True, 'itk::Image< unsigned short,2 >, itk::Image< float,2 >'),
  ('ImageShapeModelEstimatorBase', 'itk::ImageShapeModelEstimatorBase', 'itkImageShapeModelEstimatorBaseIUS2ID2', True, 'itk::Image< unsigned short,2 >, itk::Image< double,2 >'),
  ('ImageShapeModelEstimatorBase', 'itk::ImageShapeModelEstimatorBase', 'itkImageShapeModelEstimatorBaseIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('ImageShapeModelEstimatorBase', 'itk::ImageShapeModelEstimatorBase', 'itkImageShapeModelEstimatorBaseIF2ID2', True, 'itk::Image< float,2 >, itk::Image< double,2 >'),
  ('ImageShapeModelEstimatorBase', 'itk::ImageShapeModelEstimatorBase', 'itkImageShapeModelEstimatorBaseID2IF2', True, 'itk::Image< double,2 >, itk::Image< float,2 >'),
  ('ImageShapeModelEstimatorBase', 'itk::ImageShapeModelEstimatorBase', 'itkImageShapeModelEstimatorBaseID2ID2', True, 'itk::Image< double,2 >, itk::Image< double,2 >'),
  ('ImageShapeModelEstimatorBase', 'itk::ImageShapeModelEstimatorBase', 'itkImageShapeModelEstimatorBaseISS3IF3', True, 'itk::Image< signed short,3 >, itk::Image< float,3 >'),
  ('ImageShapeModelEstimatorBase', 'itk::ImageShapeModelEstimatorBase', 'itkImageShapeModelEstimatorBaseISS3ID3', True, 'itk::Image< signed short,3 >, itk::Image< double,3 >'),
  ('ImageShapeModelEstimatorBase', 'itk::ImageShapeModelEstimatorBase', 'itkImageShapeModelEstimatorBaseIUC3IF3', True, 'itk::Image< unsigned char,3 >, itk::Image< float,3 >'),
  ('ImageShapeModelEstimatorBase', 'itk::ImageShapeModelEstimatorBase', 'itkImageShapeModelEstimatorBaseIUC3ID3', True, 'itk::Image< unsigned char,3 >, itk::Image< double,3 >'),
  ('ImageShapeModelEstimatorBase', 'itk::ImageShapeModelEstimatorBase', 'itkImageShapeModelEstimatorBaseIUS3IF3', True, 'itk::Image< unsigned short,3 >, itk::Image< float,3 >'),
  ('ImageShapeModelEstimatorBase', 'itk::ImageShapeModelEstimatorBase', 'itkImageShapeModelEstimatorBaseIUS3ID3', True, 'itk::Image< unsigned short,3 >, itk::Image< double,3 >'),
  ('ImageShapeModelEstimatorBase', 'itk::ImageShapeModelEstimatorBase', 'itkImageShapeModelEstimatorBaseIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('ImageShapeModelEstimatorBase', 'itk::ImageShapeModelEstimatorBase', 'itkImageShapeModelEstimatorBaseIF3ID3', True, 'itk::Image< float,3 >, itk::Image< double,3 >'),
  ('ImageShapeModelEstimatorBase', 'itk::ImageShapeModelEstimatorBase', 'itkImageShapeModelEstimatorBaseID3IF3', True, 'itk::Image< double,3 >, itk::Image< float,3 >'),
  ('ImageShapeModelEstimatorBase', 'itk::ImageShapeModelEstimatorBase', 'itkImageShapeModelEstimatorBaseID3ID3', True, 'itk::Image< double,3 >, itk::Image< double,3 >'),
  ('LabelStatisticsImageFilter', 'itk::LabelStatisticsImageFilter', 'itkLabelStatisticsImageFilterISS2IUC2', True, 'itk::Image< signed short,2 >,itk::Image< unsigned char,2 >'),
  ('LabelStatisticsImageFilter', 'itk::LabelStatisticsImageFilter', 'itkLabelStatisticsImageFilterISS2IUS2', True, 'itk::Image< signed short,2 >,itk::Image< unsigned short,2 >'),
  ('LabelStatisticsImageFilter', 'itk::LabelStatisticsImageFilter', 'itkLabelStatisticsImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >,itk::Image< signed short,2 >'),
  ('LabelStatisticsImageFilter', 'itk::LabelStatisticsImageFilter', 'itkLabelStatisticsImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >,itk::Image< unsigned char,2 >'),
  ('LabelStatisticsImageFilter', 'itk::LabelStatisticsImageFilter', 'itkLabelStatisticsImageFilterIUC2IUS2', True, 'itk::Image< unsigned char,2 >,itk::Image< unsigned short,2 >'),
  ('LabelStatisticsImageFilter', 'itk::LabelStatisticsImageFilter', 'itkLabelStatisticsImageFilterIUC2ISS2', True, 'itk::Image< unsigned char,2 >,itk::Image< signed short,2 >'),
  ('LabelStatisticsImageFilter', 'itk::LabelStatisticsImageFilter', 'itkLabelStatisticsImageFilterIUS2IUC2', True, 'itk::Image< unsigned short,2 >,itk::Image< unsigned char,2 >'),
  ('LabelStatisticsImageFilter', 'itk::LabelStatisticsImageFilter', 'itkLabelStatisticsImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >,itk::Image< unsigned short,2 >'),
  ('LabelStatisticsImageFilter', 'itk::LabelStatisticsImageFilter', 'itkLabelStatisticsImageFilterIUS2ISS2', True, 'itk::Image< unsigned short,2 >,itk::Image< signed short,2 >'),
  ('LabelStatisticsImageFilter', 'itk::LabelStatisticsImageFilter', 'itkLabelStatisticsImageFilterIF2IUC2', True, 'itk::Image< float,2 >,itk::Image< unsigned char,2 >'),
  ('LabelStatisticsImageFilter', 'itk::LabelStatisticsImageFilter', 'itkLabelStatisticsImageFilterIF2IUS2', True, 'itk::Image< float,2 >,itk::Image< unsigned short,2 >'),
  ('LabelStatisticsImageFilter', 'itk::LabelStatisticsImageFilter', 'itkLabelStatisticsImageFilterIF2ISS2', True, 'itk::Image< float,2 >,itk::Image< signed short,2 >'),
  ('LabelStatisticsImageFilter', 'itk::LabelStatisticsImageFilter', 'itkLabelStatisticsImageFilterID2IUC2', True, 'itk::Image< double,2 >,itk::Image< unsigned char,2 >'),
  ('LabelStatisticsImageFilter', 'itk::LabelStatisticsImageFilter', 'itkLabelStatisticsImageFilterID2IUS2', True, 'itk::Image< double,2 >,itk::Image< unsigned short,2 >'),
  ('LabelStatisticsImageFilter', 'itk::LabelStatisticsImageFilter', 'itkLabelStatisticsImageFilterID2ISS2', True, 'itk::Image< double,2 >,itk::Image< signed short,2 >'),
  ('LabelStatisticsImageFilter', 'itk::LabelStatisticsImageFilter', 'itkLabelStatisticsImageFilterISS3IUC3', True, 'itk::Image< signed short,3 >,itk::Image< unsigned char,3 >'),
  ('LabelStatisticsImageFilter', 'itk::LabelStatisticsImageFilter', 'itkLabelStatisticsImageFilterISS3IUS3', True, 'itk::Image< signed short,3 >,itk::Image< unsigned short,3 >'),
  ('LabelStatisticsImageFilter', 'itk::LabelStatisticsImageFilter', 'itkLabelStatisticsImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >,itk::Image< signed short,3 >'),
  ('LabelStatisticsImageFilter', 'itk::LabelStatisticsImageFilter', 'itkLabelStatisticsImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >,itk::Image< unsigned char,3 >'),
  ('LabelStatisticsImageFilter', 'itk::LabelStatisticsImageFilter', 'itkLabelStatisticsImageFilterIUC3IUS3', True, 'itk::Image< unsigned char,3 >,itk::Image< unsigned short,3 >'),
  ('LabelStatisticsImageFilter', 'itk::LabelStatisticsImageFilter', 'itkLabelStatisticsImageFilterIUC3ISS3', True, 'itk::Image< unsigned char,3 >,itk::Image< signed short,3 >'),
  ('LabelStatisticsImageFilter', 'itk::LabelStatisticsImageFilter', 'itkLabelStatisticsImageFilterIUS3IUC3', True, 'itk::Image< unsigned short,3 >,itk::Image< unsigned char,3 >'),
  ('LabelStatisticsImageFilter', 'itk::LabelStatisticsImageFilter', 'itkLabelStatisticsImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >,itk::Image< unsigned short,3 >'),
  ('LabelStatisticsImageFilter', 'itk::LabelStatisticsImageFilter', 'itkLabelStatisticsImageFilterIUS3ISS3', True, 'itk::Image< unsigned short,3 >,itk::Image< signed short,3 >'),
  ('LabelStatisticsImageFilter', 'itk::LabelStatisticsImageFilter', 'itkLabelStatisticsImageFilterIF3IUC3', True, 'itk::Image< float,3 >,itk::Image< unsigned char,3 >'),
  ('LabelStatisticsImageFilter', 'itk::LabelStatisticsImageFilter', 'itkLabelStatisticsImageFilterIF3IUS3', True, 'itk::Image< float,3 >,itk::Image< unsigned short,3 >'),
  ('LabelStatisticsImageFilter', 'itk::LabelStatisticsImageFilter', 'itkLabelStatisticsImageFilterIF3ISS3', True, 'itk::Image< float,3 >,itk::Image< signed short,3 >'),
  ('LabelStatisticsImageFilter', 'itk::LabelStatisticsImageFilter', 'itkLabelStatisticsImageFilterID3IUC3', True, 'itk::Image< double,3 >,itk::Image< unsigned char,3 >'),
  ('LabelStatisticsImageFilter', 'itk::LabelStatisticsImageFilter', 'itkLabelStatisticsImageFilterID3IUS3', True, 'itk::Image< double,3 >,itk::Image< unsigned short,3 >'),
  ('LabelStatisticsImageFilter', 'itk::LabelStatisticsImageFilter', 'itkLabelStatisticsImageFilterID3ISS3', True, 'itk::Image< double,3 >,itk::Image< signed short,3 >'),
  ('MaximumProjectionImageFilter', 'itk::MaximumProjectionImageFilter', 'itkMaximumProjectionImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('MaximumProjectionImageFilter', 'itk::MaximumProjectionImageFilter', 'itkMaximumProjectionImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('MaximumProjectionImageFilter', 'itk::MaximumProjectionImageFilter', 'itkMaximumProjectionImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('MaximumProjectionImageFilter', 'itk::MaximumProjectionImageFilter', 'itkMaximumProjectionImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('MaximumProjectionImageFilter', 'itk::MaximumProjectionImageFilter', 'itkMaximumProjectionImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('MaximumProjectionImageFilter', 'itk::MaximumProjectionImageFilter', 'itkMaximumProjectionImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('MaximumProjectionImageFilter', 'itk::MaximumProjectionImageFilter', 'itkMaximumProjectionImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('MaximumProjectionImageFilter', 'itk::MaximumProjectionImageFilter', 'itkMaximumProjectionImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('MaximumProjectionImageFilter', 'itk::MaximumProjectionImageFilter', 'itkMaximumProjectionImageFilterID2ID2', True, 'itk::Image< double,2 >, itk::Image< double,2 >'),
  ('MaximumProjectionImageFilter', 'itk::MaximumProjectionImageFilter', 'itkMaximumProjectionImageFilterID3ID3', True, 'itk::Image< double,3 >, itk::Image< double,3 >'),
  ('MaximumProjectionImageFilter', 'itk::MaximumProjectionImageFilter', 'itkMaximumProjectionImageFilterISS3ISS2', True, 'itk::Image< signed short,3 >,itk::Image< signed short,2 >'),
  ('MaximumProjectionImageFilter', 'itk::MaximumProjectionImageFilter', 'itkMaximumProjectionImageFilterIUC3IUC2', True, 'itk::Image< unsigned char,3 >,itk::Image< unsigned char,2 >'),
  ('MaximumProjectionImageFilter', 'itk::MaximumProjectionImageFilter', 'itkMaximumProjectionImageFilterIUS3IUS2', True, 'itk::Image< unsigned short,3 >,itk::Image< unsigned short,2 >'),
  ('MaximumProjectionImageFilter', 'itk::MaximumProjectionImageFilter', 'itkMaximumProjectionImageFilterIF3IF2', True, 'itk::Image< float,3 >,itk::Image< float,2 >'),
  ('MaximumProjectionImageFilter', 'itk::MaximumProjectionImageFilter', 'itkMaximumProjectionImageFilterID3ID2', True, 'itk::Image< double,3 >,itk::Image< double,2 >'),
  ('MeanProjectionImageFilter', 'itk::MeanProjectionImageFilter', 'itkMeanProjectionImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('MeanProjectionImageFilter', 'itk::MeanProjectionImageFilter', 'itkMeanProjectionImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('MeanProjectionImageFilter', 'itk::MeanProjectionImageFilter', 'itkMeanProjectionImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('MeanProjectionImageFilter', 'itk::MeanProjectionImageFilter', 'itkMeanProjectionImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('MeanProjectionImageFilter', 'itk::MeanProjectionImageFilter', 'itkMeanProjectionImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('MeanProjectionImageFilter', 'itk::MeanProjectionImageFilter', 'itkMeanProjectionImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('MeanProjectionImageFilter', 'itk::MeanProjectionImageFilter', 'itkMeanProjectionImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('MeanProjectionImageFilter', 'itk::MeanProjectionImageFilter', 'itkMeanProjectionImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('MeanProjectionImageFilter', 'itk::MeanProjectionImageFilter', 'itkMeanProjectionImageFilterID2ID2', True, 'itk::Image< double,2 >, itk::Image< double,2 >'),
  ('MeanProjectionImageFilter', 'itk::MeanProjectionImageFilter', 'itkMeanProjectionImageFilterID3ID3', True, 'itk::Image< double,3 >, itk::Image< double,3 >'),
  ('MeanProjectionImageFilter', 'itk::MeanProjectionImageFilter', 'itkMeanProjectionImageFilterISS3ISS2', True, 'itk::Image< signed short,3 >,itk::Image< signed short,2 >'),
  ('MeanProjectionImageFilter', 'itk::MeanProjectionImageFilter', 'itkMeanProjectionImageFilterIUC3IUC2', True, 'itk::Image< unsigned char,3 >,itk::Image< unsigned char,2 >'),
  ('MeanProjectionImageFilter', 'itk::MeanProjectionImageFilter', 'itkMeanProjectionImageFilterIUS3IUS2', True, 'itk::Image< unsigned short,3 >,itk::Image< unsigned short,2 >'),
  ('MeanProjectionImageFilter', 'itk::MeanProjectionImageFilter', 'itkMeanProjectionImageFilterIF3IF2', True, 'itk::Image< float,3 >,itk::Image< float,2 >'),
  ('MeanProjectionImageFilter', 'itk::MeanProjectionImageFilter', 'itkMeanProjectionImageFilterID3ID2', True, 'itk::Image< double,3 >,itk::Image< double,2 >'),
  ('MedianProjectionImageFilter', 'itk::MedianProjectionImageFilter', 'itkMedianProjectionImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('MedianProjectionImageFilter', 'itk::MedianProjectionImageFilter', 'itkMedianProjectionImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('MedianProjectionImageFilter', 'itk::MedianProjectionImageFilter', 'itkMedianProjectionImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('MedianProjectionImageFilter', 'itk::MedianProjectionImageFilter', 'itkMedianProjectionImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('MedianProjectionImageFilter', 'itk::MedianProjectionImageFilter', 'itkMedianProjectionImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('MedianProjectionImageFilter', 'itk::MedianProjectionImageFilter', 'itkMedianProjectionImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('MedianProjectionImageFilter', 'itk::MedianProjectionImageFilter', 'itkMedianProjectionImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('MedianProjectionImageFilter', 'itk::MedianProjectionImageFilter', 'itkMedianProjectionImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('MedianProjectionImageFilter', 'itk::MedianProjectionImageFilter', 'itkMedianProjectionImageFilterID2ID2', True, 'itk::Image< double,2 >, itk::Image< double,2 >'),
  ('MedianProjectionImageFilter', 'itk::MedianProjectionImageFilter', 'itkMedianProjectionImageFilterID3ID3', True, 'itk::Image< double,3 >, itk::Image< double,3 >'),
  ('MedianProjectionImageFilter', 'itk::MedianProjectionImageFilter', 'itkMedianProjectionImageFilterISS3ISS2', True, 'itk::Image< signed short,3 >,itk::Image< signed short,2 >'),
  ('MedianProjectionImageFilter', 'itk::MedianProjectionImageFilter', 'itkMedianProjectionImageFilterIUC3IUC2', True, 'itk::Image< unsigned char,3 >,itk::Image< unsigned char,2 >'),
  ('MedianProjectionImageFilter', 'itk::MedianProjectionImageFilter', 'itkMedianProjectionImageFilterIUS3IUS2', True, 'itk::Image< unsigned short,3 >,itk::Image< unsigned short,2 >'),
  ('MedianProjectionImageFilter', 'itk::MedianProjectionImageFilter', 'itkMedianProjectionImageFilterIF3IF2', True, 'itk::Image< float,3 >,itk::Image< float,2 >'),
  ('MedianProjectionImageFilter', 'itk::MedianProjectionImageFilter', 'itkMedianProjectionImageFilterID3ID2', True, 'itk::Image< double,3 >,itk::Image< double,2 >'),
  ('MinimumMaximumImageFilter', 'itk::MinimumMaximumImageFilter', 'itkMinimumMaximumImageFilterISS2', True, 'itk::Image< signed short,2 >'),
  ('MinimumMaximumImageFilter', 'itk::MinimumMaximumImageFilter', 'itkMinimumMaximumImageFilterISS3', True, 'itk::Image< signed short,3 >'),
  ('MinimumMaximumImageFilter', 'itk::MinimumMaximumImageFilter', 'itkMinimumMaximumImageFilterIUC2', True, 'itk::Image< unsigned char,2 >'),
  ('MinimumMaximumImageFilter', 'itk::MinimumMaximumImageFilter', 'itkMinimumMaximumImageFilterIUC3', True, 'itk::Image< unsigned char,3 >'),
  ('MinimumMaximumImageFilter', 'itk::MinimumMaximumImageFilter', 'itkMinimumMaximumImageFilterIUS2', True, 'itk::Image< unsigned short,2 >'),
  ('MinimumMaximumImageFilter', 'itk::MinimumMaximumImageFilter', 'itkMinimumMaximumImageFilterIUS3', True, 'itk::Image< unsigned short,3 >'),
  ('MinimumMaximumImageFilter', 'itk::MinimumMaximumImageFilter', 'itkMinimumMaximumImageFilterIF2', True, 'itk::Image< float,2 >'),
  ('MinimumMaximumImageFilter', 'itk::MinimumMaximumImageFilter', 'itkMinimumMaximumImageFilterIF3', True, 'itk::Image< float,3 >'),
  ('MinimumMaximumImageFilter', 'itk::MinimumMaximumImageFilter', 'itkMinimumMaximumImageFilterID2', True, 'itk::Image< double,2 >'),
  ('MinimumMaximumImageFilter', 'itk::MinimumMaximumImageFilter', 'itkMinimumMaximumImageFilterID3', True, 'itk::Image< double,3 >'),
  ('MinimumProjectionImageFilter', 'itk::MinimumProjectionImageFilter', 'itkMinimumProjectionImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('MinimumProjectionImageFilter', 'itk::MinimumProjectionImageFilter', 'itkMinimumProjectionImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('MinimumProjectionImageFilter', 'itk::MinimumProjectionImageFilter', 'itkMinimumProjectionImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('MinimumProjectionImageFilter', 'itk::MinimumProjectionImageFilter', 'itkMinimumProjectionImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('MinimumProjectionImageFilter', 'itk::MinimumProjectionImageFilter', 'itkMinimumProjectionImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('MinimumProjectionImageFilter', 'itk::MinimumProjectionImageFilter', 'itkMinimumProjectionImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('MinimumProjectionImageFilter', 'itk::MinimumProjectionImageFilter', 'itkMinimumProjectionImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('MinimumProjectionImageFilter', 'itk::MinimumProjectionImageFilter', 'itkMinimumProjectionImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('MinimumProjectionImageFilter', 'itk::MinimumProjectionImageFilter', 'itkMinimumProjectionImageFilterID2ID2', True, 'itk::Image< double,2 >, itk::Image< double,2 >'),
  ('MinimumProjectionImageFilter', 'itk::MinimumProjectionImageFilter', 'itkMinimumProjectionImageFilterID3ID3', True, 'itk::Image< double,3 >, itk::Image< double,3 >'),
  ('MinimumProjectionImageFilter', 'itk::MinimumProjectionImageFilter', 'itkMinimumProjectionImageFilterISS3ISS2', True, 'itk::Image< signed short,3 >,itk::Image< signed short,2 >'),
  ('MinimumProjectionImageFilter', 'itk::MinimumProjectionImageFilter', 'itkMinimumProjectionImageFilterIUC3IUC2', True, 'itk::Image< unsigned char,3 >,itk::Image< unsigned char,2 >'),
  ('MinimumProjectionImageFilter', 'itk::MinimumProjectionImageFilter', 'itkMinimumProjectionImageFilterIUS3IUS2', True, 'itk::Image< unsigned short,3 >,itk::Image< unsigned short,2 >'),
  ('MinimumProjectionImageFilter', 'itk::MinimumProjectionImageFilter', 'itkMinimumProjectionImageFilterIF3IF2', True, 'itk::Image< float,3 >,itk::Image< float,2 >'),
  ('MinimumProjectionImageFilter', 'itk::MinimumProjectionImageFilter', 'itkMinimumProjectionImageFilterID3ID2', True, 'itk::Image< double,3 >,itk::Image< double,2 >'),
  ('StandardDeviationProjectionImageFilter', 'itk::StandardDeviationProjectionImageFilter', 'itkStandardDeviationProjectionImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('StandardDeviationProjectionImageFilter', 'itk::StandardDeviationProjectionImageFilter', 'itkStandardDeviationProjectionImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('StandardDeviationProjectionImageFilter', 'itk::StandardDeviationProjectionImageFilter', 'itkStandardDeviationProjectionImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('StandardDeviationProjectionImageFilter', 'itk::StandardDeviationProjectionImageFilter', 'itkStandardDeviationProjectionImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('StandardDeviationProjectionImageFilter', 'itk::StandardDeviationProjectionImageFilter', 'itkStandardDeviationProjectionImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('StandardDeviationProjectionImageFilter', 'itk::StandardDeviationProjectionImageFilter', 'itkStandardDeviationProjectionImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('StandardDeviationProjectionImageFilter', 'itk::StandardDeviationProjectionImageFilter', 'itkStandardDeviationProjectionImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('StandardDeviationProjectionImageFilter', 'itk::StandardDeviationProjectionImageFilter', 'itkStandardDeviationProjectionImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('StandardDeviationProjectionImageFilter', 'itk::StandardDeviationProjectionImageFilter', 'itkStandardDeviationProjectionImageFilterID2ID2', True, 'itk::Image< double,2 >, itk::Image< double,2 >'),
  ('StandardDeviationProjectionImageFilter', 'itk::StandardDeviationProjectionImageFilter', 'itkStandardDeviationProjectionImageFilterID3ID3', True, 'itk::Image< double,3 >, itk::Image< double,3 >'),
  ('StandardDeviationProjectionImageFilter', 'itk::StandardDeviationProjectionImageFilter', 'itkStandardDeviationProjectionImageFilterISS3ISS2', True, 'itk::Image< signed short,3 >,itk::Image< signed short,2 >'),
  ('StandardDeviationProjectionImageFilter', 'itk::StandardDeviationProjectionImageFilter', 'itkStandardDeviationProjectionImageFilterIUC3IUC2', True, 'itk::Image< unsigned char,3 >,itk::Image< unsigned char,2 >'),
  ('StandardDeviationProjectionImageFilter', 'itk::StandardDeviationProjectionImageFilter', 'itkStandardDeviationProjectionImageFilterIUS3IUS2', True, 'itk::Image< unsigned short,3 >,itk::Image< unsigned short,2 >'),
  ('StandardDeviationProjectionImageFilter', 'itk::StandardDeviationProjectionImageFilter', 'itkStandardDeviationProjectionImageFilterIF3IF2', True, 'itk::Image< float,3 >,itk::Image< float,2 >'),
  ('StandardDeviationProjectionImageFilter', 'itk::StandardDeviationProjectionImageFilter', 'itkStandardDeviationProjectionImageFilterID3ID2', True, 'itk::Image< double,3 >,itk::Image< double,2 >'),
  ('StatisticsImageFilter', 'itk::StatisticsImageFilter', 'itkStatisticsImageFilterISS2', True, 'itk::Image< signed short,2 >'),
  ('StatisticsImageFilter', 'itk::StatisticsImageFilter', 'itkStatisticsImageFilterISS3', True, 'itk::Image< signed short,3 >'),
  ('StatisticsImageFilter', 'itk::StatisticsImageFilter', 'itkStatisticsImageFilterIUC2', True, 'itk::Image< unsigned char,2 >'),
  ('StatisticsImageFilter', 'itk::StatisticsImageFilter', 'itkStatisticsImageFilterIUC3', True, 'itk::Image< unsigned char,3 >'),
  ('StatisticsImageFilter', 'itk::StatisticsImageFilter', 'itkStatisticsImageFilterIUS2', True, 'itk::Image< unsigned short,2 >'),
  ('StatisticsImageFilter', 'itk::StatisticsImageFilter', 'itkStatisticsImageFilterIUS3', True, 'itk::Image< unsigned short,3 >'),
  ('StatisticsImageFilter', 'itk::StatisticsImageFilter', 'itkStatisticsImageFilterIF2', True, 'itk::Image< float,2 >'),
  ('StatisticsImageFilter', 'itk::StatisticsImageFilter', 'itkStatisticsImageFilterIF3', True, 'itk::Image< float,3 >'),
  ('StatisticsImageFilter', 'itk::StatisticsImageFilter', 'itkStatisticsImageFilterID2', True, 'itk::Image< double,2 >'),
  ('StatisticsImageFilter', 'itk::StatisticsImageFilter', 'itkStatisticsImageFilterID3', True, 'itk::Image< double,3 >'),
  ('SumProjectionImageFilter', 'itk::SumProjectionImageFilter', 'itkSumProjectionImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('SumProjectionImageFilter', 'itk::SumProjectionImageFilter', 'itkSumProjectionImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('SumProjectionImageFilter', 'itk::SumProjectionImageFilter', 'itkSumProjectionImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('SumProjectionImageFilter', 'itk::SumProjectionImageFilter', 'itkSumProjectionImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('SumProjectionImageFilter', 'itk::SumProjectionImageFilter', 'itkSumProjectionImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('SumProjectionImageFilter', 'itk::SumProjectionImageFilter', 'itkSumProjectionImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('SumProjectionImageFilter', 'itk::SumProjectionImageFilter', 'itkSumProjectionImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('SumProjectionImageFilter', 'itk::SumProjectionImageFilter', 'itkSumProjectionImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('SumProjectionImageFilter', 'itk::SumProjectionImageFilter', 'itkSumProjectionImageFilterID2ID2', True, 'itk::Image< double,2 >, itk::Image< double,2 >'),
  ('SumProjectionImageFilter', 'itk::SumProjectionImageFilter', 'itkSumProjectionImageFilterID3ID3', True, 'itk::Image< double,3 >, itk::Image< double,3 >'),
  ('SumProjectionImageFilter', 'itk::SumProjectionImageFilter', 'itkSumProjectionImageFilterISS3ISS2', True, 'itk::Image< signed short,3 >,itk::Image< signed short,2 >'),
  ('SumProjectionImageFilter', 'itk::SumProjectionImageFilter', 'itkSumProjectionImageFilterIUC3IUC2', True, 'itk::Image< unsigned char,3 >,itk::Image< unsigned char,2 >'),
  ('SumProjectionImageFilter', 'itk::SumProjectionImageFilter', 'itkSumProjectionImageFilterIUS3IUS2', True, 'itk::Image< unsigned short,3 >,itk::Image< unsigned short,2 >'),
  ('SumProjectionImageFilter', 'itk::SumProjectionImageFilter', 'itkSumProjectionImageFilterIF3IF2', True, 'itk::Image< float,3 >,itk::Image< float,2 >'),
  ('SumProjectionImageFilter', 'itk::SumProjectionImageFilter', 'itkSumProjectionImageFilterID3ID2', True, 'itk::Image< double,3 >,itk::Image< double,2 >'),
)
snake_case_functions = ('accumulate_image_filter', 'label_statistics_image_filter', 'minimum_maximum_image_filter', 'binary_projection_image_filter', 'minimum_projection_image_filter', 'maximum_projection_image_filter', 'standard_deviation_projection_image_filter', 'sum_projection_image_filter', 'mean_projection_image_filter', 'median_projection_image_filter', 'image_shape_model_estimator_base', 'projection_image_filter', 'image_pca_shape_model_estimator', 'statistics_image_filter', )
